#!/usr/bin/env python3
from django.core.management.base import BaseCommand, CommandError

from arkindex.process.models import Worker, WorkerType, WorkerVersion


class Command(BaseCommand):
    help = 'Create a fake worker version'

    def add_arguments(self, parser):
        parser.add_argument(
            "--name",
            help="Name of the worker",
            required=True
        )
        parser.add_argument(
            "--slug",
            help="Slug of the worker",
            required=True
        )

    def handle(self, name, slug, *args, **options):
        versions = WorkerVersion.objects.filter(worker__slug=slug)
        if versions.exists():
            versions_id = list(versions.values_list('id', flat=True).distinct())
            raise CommandError(f"This worker already has versions: {versions_id}")
            return

        worker_type, _ = WorkerType.objects.get_or_create(
            slug="classifier",
            defaults={'display_name': "classifier"}
        )

        worker, _ = Worker.objects.get_or_create(
            name=name,
            slug=slug,
            type=worker_type,
        )

        last_worker_version = worker.versions.order_by('version').last()
        version = last_worker_version.version + 1 if last_worker_version else 1

        worker_version = WorkerVersion.objects.create(
            worker=worker,
            configuration={"configuration": {}},
            version=version
        )

        self.stdout.write(self.style.SUCCESS(f"Created a worker version: {worker_version.id}"))
